@@ -3,7 +3,7 @@ package Locale::TextDomain::OO; ## no critic (TidyCode)
 use strict;
 use warnings;
 
-our $VERSION = '1.016';
+our $VERSION = '1.017';
 
 use Locale::TextDomain::OO::Translator;
 
@@ -36,13 +36,13 @@ __END__
 
 Locale::TextDomain::OO - Perl OO Interface to Uniforum Message Translation
 
-$Id: OO.pm 551 2014-11-01 06:46:51Z steffenw $
+$Id: OO.pm 573 2015-02-07 20:59:51Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO.pm $
 
 =head1 VERSION
 
-1.016
+1.017
 
 Starting with version 1.000 the interface has changed.
 
@@ -70,16 +70,56 @@ Locale::TextDomain::OO has a flexible object oriented interface
 based on L<Moo|Moo>.
 
 Creating the Lexicon and translating are two splitted things.
-So it is possible to create the lexicon during the initialisation phase.
+So it is possible to create the lexicon during the initialization phase.
 The connection between both is the singleton mechanimsm of the lexicon module.
 
-=head2 How to extract?
+=head2 Plugin for the web framework?
 
-Use module Locale::TextDomain::OO::Extract.
+This module is currently used in a Catalyst based web project.
+
+It is great to call everything on the Catalyst context object.
+It is was great until we used module in web and shell scripts together
+and called the translation methods there.
+
+What we have done was removing the Catalyst maketext plugin.
+We are using a role in the Catalyst application
+and so we can call all the translation methods
+on the Catalyst context object like before.
+
+For the shell scripts we have a role for this Cmd's
+to call all the methods on C<$self>.
+
+In that roles we delegate a bunch of methods
+to Locale::TextDomain::OO.
+We also added our project specific methods there.
+
+Write you own role. There is no need for a common plugin.
+
+=head2 Who is setting the languages?
+
+Not this module.
+
+In a web application are lots of ideas to do that.
+But never we use the server settings, never.
+
+The HTTP request contains that information.
+Extend this with super and panic languages.
+Normally you support only a bunch of world languages, so reduce.
+This module will find the first match.
+
+Or you store and get the language in the session.
+
+Or your application has a language selection menu.
+
+=head2 How to extract the project files?
+
+Use module
+L<Locale::TextDomain::OO::Extract|Locale::TextDomain::OO::Extract>.
 This is a base class for all source scanner to create pot files.
 Use this base class and give this module the rules
 or use one of the already exteded classes.
-Locale::TextDomain::OO::Extract::Perl is a extension for Perl code and so on.
+L<Locale::TextDomain::OO::Extract::Perl|Locale::TextDomain::OO::Extract::Perl>
+is a extension for Perl code and so on.
 
 =head2 Do not follow the dead end of Locale::Maketext!
 
@@ -167,7 +207,7 @@ Named placeholders.
 
 =back
 
-=head2 More informations
+=head2 More information
 
 Run the examples of this distribution (folder example).
 
@@ -210,8 +250,10 @@ Run the examples of this distribution (folder example).
  `-----------'   `-----------'       `----------'       `----------'   |
                                        ^                   ^           |
                                        |                   |           |
-                                  build using        build using       |
-                                  gettext tools      gettext tools     |
+                        build using gettext tools                      |
+                        or Locale::TextDomain::OO::Extract             |
+                        and Locale::TextDomain::OO::Extract::Process   |
+                        if both are released                           |
                                                                        |
                                   .------------------------------------'
                                   |
@@ -298,7 +340,7 @@ Instead of method new call method instance to get a singleton.
     );
     $same_instance = Locale::TextDomain::OO->instance;
 
-=head2 Attributes handled with plugin Expand::Gettext
+=head2 Attributes handled with plugin Expand::Gettext::Loc
 
 This plugin can handle named placeholders like C<{name}>.
 For numeric placeholders add attribute C<:num>.
@@ -329,25 +371,15 @@ Add the modifier code like that to handle that attributes.
         },
     );
 
-=head2 Attributes handled with plugin Expand::Gettext::Loc
+=head2 Attributes handled with plugin Expand::Gettext
 
 Like before but a little difference. Instead of
 
-    $loc->expand_gettext->modifier_code(...
-
-write
-
     $loc->expand_gettext_loc->modifier_code(...
 
-=head2 Attributes handled with plugin Expand::Gettext::Loc
-
-Like before but a little difference. Instead of
-
-    $loc->expand_gettext->modifier_code(...
-
 write
 
-    $loc->expand_gettext_named->modifier_code(...
+    $loc->expand_gettext->modifier_code(...
 
 =head2 Localize numbers with plugin Expand::Maketext
 
@@ -508,20 +540,20 @@ The examples there are rewritten and explained here.
 
 =head2 string interpolation and joined strings
 
-    print <<"EOF";
-        $loc->__(
+    print <<"EOT";
+        $loc->loc_(
             'The dot operator'
             . ' does not work'
             . ' here!'
         )
-        Likewise, you cannot @{[ $loc->__('interpolate function calls') ]}
+        Likewise, you cannot @{[ $loc->loc_('interpolate function calls') ]}
         inside quoted strings or quote-like expressions.
-    EOF
+    EOT
 
 The fist call can not work.
 Methods are not callable in interpolated strings/"here documents".
 The . operator is normally not implemented at the extractor.
-The first parameter of method __ must be a constant.
+The first parameter of method loc_ must be a constant.
 
 There is no problem for the second call because the extractor
 extracts the Perl file as text and did not parse the code.
@@ -530,17 +562,17 @@ extracts the Perl file as text and did not parse the code.
 
 This example is no problem here, because the file is extracted as text.
 
-    s/<!--START_OF_WEEK-->/$loc->__('Sunday')/e;
+    s/<!--START_OF_WEEK-->/$loc->loc_('Sunday')/e;
 
 =head2 named placeholders
 
-Method __ is an alias for method __x.
+Method loc_ is an alias for method loc_x.
 But {OPTIONS} is not a placeholder
 because key "OPTIONS" is not in parameters.
 
-    die $loc->__("usage: $0 {OPTIONS} FILENAME...\n");
+    die $loc->loc_("usage: $0 {OPTIONS} FILENAME...\n");
 
-    die $loc->__x("usage: {program} {OPTIONS} FILENAME...\n", program => $0);
+    die $loc->loc_x("usage: {program} {OPTIONS} FILENAME...\n", program => $0);
 
 =head1 SEE ALSO
 
@@ -563,7 +595,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009 - 2014,
+Copyright (c) 2009 - 2015,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
