@@ -10,7 +10,7 @@ use MooX::StrictConstructor;
 use MooX::Types::MooseLike::Base qw(Str);
 use namespace::autoclean;
 
-our $VERSION = '1.014';
+our $VERSION = '1.017';
 
 with qw(
     Locale::TextDomain::OO::Role::Logger
@@ -135,7 +135,7 @@ sub translate { ## no critic (ExcessComplexity ManyArgs)
                 and $self->logger->(
                     (
                         sprintf
-                            '%s msgstr_plural not found for for msgctxt=%s, msgid=%s, msgid_plural=%s.',
+                            '%s msgstr_plural not found for msgctxt=%s, msgid=%s, msgid_plural=%s.',
                             $text,
                             ( defined $msgctxt      ? qq{"$msgctxt"}      : 'undef' ),
                             ( defined $msgid        ? qq{"$msgid"}        : 'undef' ),
@@ -199,13 +199,13 @@ __END__
 
 Locale::TextDomain::OO::Translator - Translator class
 
-$Id: Translator.pm 546 2014-10-31 09:35:19Z steffenw $
+$Id: Translator.pm 573 2015-02-07 20:59:51Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO/Translator.pm $
 
 =head1 VERSION
 
-1.014
+1.017
 
 =head1 DESCRIPTION
 
@@ -282,7 +282,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2013 - 2014,
+Copyright (c) 2013 - 2017,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
